//
// =======================================================
//
// mefi++
// 
// A Chrome extension that adds features to metafilter.com
//
// v1.0, no license, free to modify
//
// Feature:
// - Remove the "Post Comment" and "Preview" buttons if
// the comment being written matches certain strings.
//
// =======================================================
// 
// This script is injected into any pages that match
// https://*.metafilter.com/*
//
// =======================================================
// 

//
// ===================================
// Variables, options and declarations
// ===================================
//

// A "regex" that checks for any text strings that match:
// an 'n' followed by any letter, two 'g's, any letter, and 'r' or 'h'.
let mfr = /n[\w-]g{2}[\w-][rh]/;

// A message that will be added to the comment box if the comment matches the above regex.
let message = "\n\nPlease make sure your comment does not include any slurs.\nReload the page to reenable the post buttons!";

var mfc; // Comment box.
var mfp; // Post button.



//
// ===============================
// Code, actions, and interactions
// ===============================
//



// When a metafilter page loads, set up this script.
window.onload = setup;

function setup() {
	
	// Find the metafilter page elements.
	mfc = document.getElementById("comment");
	mfp = document.getElementById("postButton");
	
	// Listen for input to the comment box.
	mfc.addEventListener("input", react);
	
}

// Every time the comment box contents change,
function react(e) {

	// if the content of the comment field matches the regex,
	if(mfr.exec(mfc.value)) {
	
		// remove the post button,
		mfp.parentNode.remove(mfp);
		
		// add a message to the comment box,
		document.getElementById("comment").value += message;
		
		// and stop listening for input.
		mfc.removeEventListener("input", react);
		
	}
	
}


//
// =======
// The End
// =======
//
